CardGenerator class abstract

Abstract base class for card generators

Implementers

Constructors

CardGenerator({FileManager? fileManager})

Properties

fileExtension → String
Get the file extension for this card type
no setter
fileManager → FileManager
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateCard(WalletCard card) → Future<File>
Generate a wallet card file
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validateCard(WalletCard card) → void
Validate card data

Operators

operator ==(Object other) → bool
The equality operator.
inherited