WalletCard class

Unified wallet card model that supports both Apple Wallet and Google Wallet

Annotations
  • @JsonSerializable.new()

Constructors

WalletCard({required String id, required WalletCardType type, required Map<String, dynamic> platformData, required WalletCardMetadata metadata, WalletCardVisuals? visuals, File? file})
const
WalletCard.fromJson(Map<String, dynamic> json)
factory

Properties

file → File?
Associated file (if any)
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique identifier for the card
final
metadata → WalletCardMetadata
Card metadata
final
platformData → Map<String, dynamic>
Platform-specific data
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type → WalletCardType
Card type (store card, event ticket, boarding pass, etc.)
final
visuals → WalletCardVisuals?
Visual elements
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited