WalletCardMetadata class

Card metadata

Annotations
  • @JsonSerializable.new()

Constructors

WalletCardMetadata({required String title, String? subtitle, String? description, required String organizationName, required String serialNumber, DateTime? expirationDate, DateTime? relevantDate, List<WalletCardLocation>? locations, Map<String, String>? customFields})
const
WalletCardMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

customFields → Map<String, String>?
final
description → String?
final
expirationDate → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
locations → List<WalletCardLocation>?
final
organizationName → String
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
relevantDate → DateTime?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNumber → String
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
subtitle → String?
final
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited